==> use-saga-reducer-1.1.1.tgz: package/dist-src/index.spec.js <==
import React from 'react';
import { takeEvery, put, select, delay, getContext, setContext } from 'redux-saga/effects';
import { render, fireEvent, act } from '@testing-library/react';
import useSagaReducer, { SagaProvider } from '.';
function flushPromiseQueue() {
    return new Promise((resolve) => {
        setTimeout(() => {
            resolve();
        }, 0);
    });
}
describe('useSagaReducer()', () => {
    it('yields actions taken by `takeEvery`', async () => {
        const testCaller = jest.fn();
        const testAction = {
            type: 'TEST'
        };
        const testPutAction = {
            type: 'TEST_PUT'
        };
        const testReducer = jest.fn((state = {}, action) => {
            return state;
        });
        function* testSaga() {
            yield put(testPutAction);
            yield takeEvery(testAction.type, testCaller);
        }
        function TestUseSagaReducer() {
            const [, dispatch] = useSagaReducer(testSaga, testReducer, {});
            return (React.createElement("div", null,
                React.createElement("button", { "data-testid": 'button', onClick: () => {
                        dispatch(testAction);
                    } }, "TEST")));
        }
        const { getByTestId } = render(React.createElement(TestUseSagaReducer, null));
        const button = getByTestId('button');
        expect(testReducer).toHaveBeenCalledWith({}, testPutAction);
        fireEvent.click(button);
        await flushPromiseQueue();
        expect(testCaller.mock.calls.length).toBe(1);
        fireEvent.click(button);
        await flushPromiseQueue();
        expect(testCaller.mock.calls.length).toBe(2);
    });
    it('saga can update the state using put actions', async () => {
        const testReducer = jest.fn((state = {}, action) => {
            if (action.payload) {
                return action.payload;
            }
            return state;
        });
        function* testSaga() {
            yield delay(0);
            const state = yield select();
            yield put({
                type: 'UPDATE',
                payload: {
                    count: state.count + 1
                }
            });
        }
        function TestUseSagaReducer() {
            const [state] = useSagaReducer(testSaga, testReducer, { count: 1 });
            return React.createElement("div", { "data-testid": 'test' }, state.count);
        }
        const { getByTestId } = render(React.createElement(TestUseSagaReducer, null));
        const el = getByTestId('test');
        expect(el.textContent).toBe('1');
        await act(flushPromiseQueue);
        expect(el.textContent).toBe('2');
    });
    it('saga updates the state available to yield select()', async () => {
        let testState;
        const testReducer = jest.fn((state = {}, action) => {
            if (action.type === 'INCREMENT') {
                return {
                    count: state.count + 1
                };
            }
            return state;
        });
        function* increment() {
            const state = yield select();
            testState = state;
        }
        function* testSaga() {
            yield takeEvery('INCREMENT', increment);
        }
        function TestUseSagaReducer() {
            const [, dispatch] = useSagaReducer(testSaga, testReducer, { count: 1 });
            return (React.createElement("div", null,
                React.createElement("button", { "data-testid": 'button', onClick: () => {
                        dispatch({
                            type: 'INCREMENT'
                        });
                    } }, "TEST")));
        }
        const { getByTestId } = render(React.createElement(TestUseSagaReducer, null));
        const button = getByTestId('button');
        fireEvent.click(button);
        await act(flushPromiseQueue);
        expect(testState).toEqual({ count: 2 });
        fireEvent.click(button);
        await act(flushPromiseQueue);
        expect(testState).toEqual({ count: 3 });
    });
    it('provides context values in sagas passed to provider', async () => {
        const testReducer = jest.fn((state = {}, action) => {
            return state;
        });
        function* updateContextValue({ payload }) {
            yield setContext({ foo: payload });
            const contextValue = yield getContext('foo');
            yield put({
                type: 'CONTEXT_VALUE',
                payload: contextValue
            });
        }
        function* testSaga() {
            const contextValue = yield getContext('foo');
            yield put({
                type: 'CONTEXT_VALUE',
                payload: contextValue
            });
            yield takeEvery('UPDATE_CONTEXT', updateContextValue);
        }
        const globalState = { foo: 'bar' };
        function TestApp() {
            return (React.createElement(SagaProvider, { value: globalState },
                React.createElement(TestUseSagaReducer, null)));
        }
        function TestUseSagaReducer() {
            const [, dispatch] = useSagaReducer(testSaga, testReducer, {});
            return (React.createElement("div", null,
                React.createElement("button", { "data-testid": 'button', onClick: () => {
                        dispatch({
                            type: 'UPDATE_CONTEXT',
                            payload: 'baz'
                        });
                    } }, "TEST")));
        }
        const { getByTestId } = render(React.createElement(TestApp, null));
        const button = getByTestId('button');
        expect(testReducer).toHaveBeenCalledWith({}, { type: 'CONTEXT_VALUE', payload: 'bar' });
        fireEvent.click(button);
        await flushPromiseQueue();
        expect(testReducer).toHaveBeenNthCalledWith(2, {}, { type: 'UPDATE_CONTEXT', payload: 'baz' });
        expect(testReducer).toHaveBeenNthCalledWith(3, {}, { type: 'CONTEXT_VALUE', payload: 'baz' });
    });
});

==> use-saga-reducer-2.0.0.tgz: package/dist-src/index.spec.js <==
import React from 'react';
import { takeEvery, put, select, delay, getContext, setContext } from 'redux-saga/effects';
import { render, fireEvent, act } from '@testing-library/react';
import useSagaReducer, { SagaProvider } from '.';
function flushPromiseQueue() {
    return new Promise((resolve) => {
        setTimeout(() => {
            resolve();
        }, 0);
    });
}
describe('useSagaReducer()', () => {
    it('yields actions taken by `takeEvery`', async () => {
        const testCaller = jest.fn();
        const testAction = {
            type: 'TEST'
        };
        const testPutAction = {
            type: 'TEST_PUT'
        };
        const testReducer = jest.fn((state = {}, action) => {
            return state;
        });
        function* testSaga() {
            yield put(testPutAction);
            yield takeEvery(testAction.type, testCaller);
        }
        function TestUseSagaReducer() {
            const [, dispatch] = useSagaReducer(testSaga, testReducer, {});
            return (React.createElement("div", null,
                React.createElement("button", { "data-testid": 'button', onClick: () => {
                        dispatch(testAction);
                    } }, "TEST")));
        }
        const { getByTestId } = render(React.createElement(TestUseSagaReducer, null));
        const button = getByTestId('button');
        expect(testReducer).toHaveBeenCalledWith({}, testPutAction);
        fireEvent.click(button);
        await flushPromiseQueue();
        expect(testCaller.mock.calls.length).toBe(1);
        fireEvent.click(button);
        await flushPromiseQueue();
        expect(testCaller.mock.calls.length).toBe(2);
    });
    it('saga can update the state using put actions', async () => {
        const testReducer = jest.fn((state = {}, action) => {
            if (action.payload) {
                return action.payload;
            }
            return state;
        });
        function* testSaga() {
            yield delay(0);
            const state = yield select();
            yield put({
                type: 'UPDATE',
                payload: {
                    count: state.count + 1
                }
            });
        }
        function TestUseSagaReducer() {
            const [state] = useSagaReducer(testSaga, testReducer, { count: 1 });
            return React.createElement("div", { "data-testid": 'test' }, state.count);
        }
        const { getByTestId } = render(React.createElement(TestUseSagaReducer, null));
        const el = getByTestId('test');
        expect(el.textContent).toBe('1');
        await act(flushPromiseQueue);
        expect(el.textContent).toBe('2');
    });
    it('saga updates the state available to yield select()', async () => {
        let testState;
        const testReducer = jest.fn((state = {}, action) => {
            if (action.type === 'INCREMENT') {
                return {
                    count: state.count + 1
                };
            }
            if (action.type === 'SET') {
                return {
                    count: action.payload
                };
            }
            return state;
        });
        function* increment() {
            const { count } = yield select();
            testState = count;
        }
        function* incrementAsync() {
            const state = yield select();
            yield put({
                type: 'SET',
                payload: state.count + 1
            });
            yield delay(0);
            const { count } = yield select();
            testState = count;
        }
        function* testSaga() {
            yield takeEvery('INCREMENT', increment);
            yield takeEvery('INCREMENT_ASYNC', incrementAsync);
        }
        function TestUseSagaReducer() {
            const [, dispatch] = useSagaReducer(testSaga, testReducer, { count: 1 });
            return (React.createElement("div", null,
                React.createElement("button", { "data-testid": 'button', onClick: () => {
                        dispatch({
                            type: 'INCREMENT'
                        });
                    } }, "TEST"),
                React.createElement("button", { "data-testid": 'button-async', onClick: () => {
                        dispatch({
                            type: 'INCREMENT_ASYNC'
                        });
                    } }, "TEST")));
        }
        const { getByTestId } = render(React.createElement(TestUseSagaReducer, null));
        const button = getByTestId('button');
        const buttonAsync = getByTestId('button-async');
        fireEvent.click(button);
        await act(flushPromiseQueue);
        expect(testState).toEqual(2);
        fireEvent.click(button);
        await act(flushPromiseQueue);
        expect(testState).toEqual(3);
        fireEvent.click(buttonAsync);
        await act(flushPromiseQueue);
        // Add a second flush here, once to wait for microtasks queue from put,
        // second one to wait for timer queue from delay task
        await act(flushPromiseQueue);
        expect(testState).toEqual(4);
    });
    it('provides context values in sagas passed to provider', async () => {
        const testReducer = jest.fn((state = {}, action) => {
            return state;
        });
        function* updateContextValue({ payload }) {
            yield setContext({ foo: payload });
            const contextValue = yield getContext('foo');
            yield put({
                type: 'CONTEXT_VALUE',
                payload: contextValue
            });
        }
        function* testSaga() {
            const contextValue = yield getContext('foo');
            yield put({
                type: 'CONTEXT_VALUE',
                payload: contextValue
            });
            yield takeEvery('UPDATE_CONTEXT', updateContextValue);
        }
        const globalState = { foo: 'bar' };
        function TestApp() {
            return (React.createElement(SagaProvider, { value: globalState },
                React.createElement(TestUseSagaReducer, null)));
        }
        function TestUseSagaReducer() {
            const [, dispatch] = useSagaReducer(testSaga, testReducer, {});
            return (React.createElement("div", null,
                React.createElement("button", { "data-testid": 'button', onClick: () => {
                        dispatch({
                            type: 'UPDATE_CONTEXT',
                            payload: 'baz'
                        });
                    } }, "TEST")));
        }
        const { getByTestId } = render(React.createElement(TestApp, null));
        const button = getByTestId('button');
        expect(testReducer).toHaveBeenCalledWith({}, { type: 'CONTEXT_VALUE', payload: 'bar' });
        fireEvent.click(button);
        await flushPromiseQueue();
        expect(testReducer).toHaveBeenNthCalledWith(2, {}, { type: 'UPDATE_CONTEXT', payload: 'baz' });
        expect(testReducer).toHaveBeenNthCalledWith(3, {}, { type: 'CONTEXT_VALUE', payload: 'baz' });
    });
});
